@@ -30,10 +30,10 @@ class MySQLTranslator(SQLTranslator):
     DATA_TYPE_MAPPING = DataTypeMapping(
         boolean="SIGNED",
         date="DATE",
-        float="DECIMAL",
+        float="DOUBLE",
         integer="UNSIGNED",
         text="CHAR",
-        datetime="TIMESTAMP",
+        datetime="DATETIME",
         timestamp="TIMESTAMP",
     )
     # Requires MySQL>=8
